# container

## Schema Container

在 pod 中运行的单应用容器

### Attributes

|Name and Description|Type|Default Value|Required|
|--------------------|----|-------------|--------|
|**image**<br />Docker 镜像名称|str|Undefined|**required**|
|**ports**<br />容器对外暴露的端口列表|[frontend.ContainerPort]|Undefined|optional|
## Schema ContainerPort

ContainerPort 表示单个容器中的一个网络端口

### Attributes

|Name and Description|Type|Default Value|Required|
|--------------------|----|-------------|--------|
|**port**<br />在 pod IP 地址上暴露的端口号。必须是合法的端口号：介于 0 和 65536 之间（不包含）|int|Undefined|**required**|
|**protocol**<br />端口协议，合法取值有："UDP"，"TCP"，"SCTP"|"TCP" &#124; "UDP" &#124; "SCTP"|"TCP"|**required**|
<!-- Auto generated by kcl-doc tool, please do not edit. -->
